Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1141)

Unified Diff: Source/core/layout/style/SVGLayoutStyle.h

Issue 1001833002: Rename default -> initial style and use singletons. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/layout/style/LayoutStyle.cpp ('k') | Source/core/layout/style/SVGLayoutStyle.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/layout/style/SVGLayoutStyle.h
diff --git a/Source/core/layout/style/SVGLayoutStyle.h b/Source/core/layout/style/SVGLayoutStyle.h
index f3710128ea83b020c5dbdf7f32fb1a8faed8c5bf..d38856308af46f0f54e953a5b57c64b65cd3d155 100644
--- a/Source/core/layout/style/SVGLayoutStyle.h
+++ b/Source/core/layout/style/SVGLayoutStyle.h
@@ -447,11 +447,11 @@ protected:
DataRef<StyleResourceData> resources;
private:
- enum CreateDefaultType { CreateDefault };
+ enum CreateInitialType { CreateInitial };
SVGLayoutStyle();
SVGLayoutStyle(const SVGLayoutStyle&);
- SVGLayoutStyle(CreateDefaultType); // Used to create the default style.
+ SVGLayoutStyle(CreateInitialType); // Used to create the initial style singleton.
bool diffNeedsLayoutAndPaintInvalidation(const SVGLayoutStyle* other) const;
bool diffNeedsPaintInvalidation(const SVGLayoutStyle* other) const;
« no previous file with comments | « Source/core/layout/style/LayoutStyle.cpp ('k') | Source/core/layout/style/SVGLayoutStyle.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698